Newsweek - National News, World News, Health, Technology, Entertainment and more... - Newsweek.com
Description: Newsweek magazine online plus daily news, features and commentary from our global network of correspondents

SUBSCRIBE

- Login
- Register

Login
Username:
Password:
Forgot password?/Register Now Close
SUBSCRIBE

- # Did Summit Change Anything?

  Early indications: Probably not

  ##

  The most illuminating part of Obama’s health-care reform meeting was what happened right after: GOP and Dem leaders reiterated their old talking points.

  - FactCheck: Summit Rife With Errors
  - The Obama-McCain Smackdown

  ### Related Articles

  - The Substantive, Boring Summit
  - Ezra Klein: Summit Will Make Things Worse
  - Dems Aren’t Talking Reconciliation
  P. Martinez Monsivais / AP View More Multimedia »

- # Congressional Kabuki

  What have we learned about Toyota?

  ##

  After watching some 14 hours of the hearings on C-Span, we didn't learn much. In fact, the most interesting thing to happen regarding Toyota over the last two days was when the FBI raided three of the company's suppliers outside of Detroit.

  - Toyota & Hummer: Too Big?
  - Photos: Product Recalls of the Past

  ### Related Articles

  - Toyota’s Digital Disaster
  - Getting Toyota Back On Track
  - Toyota's Mysterious Black Boxes
  Alex Wong / Getty Images View More Multimedia »

- # So Long, Salad Days

  So much for Russia as 'energy superpower'

  ##

  12

  Just two years ago, Russia's energy reserves made it seem like a rising superpower--and a Western bogeyman that could do anything it wanted. That was then.

  - Photos of a Steel City in Decline

  ### Related Articles

  - A Killer Deal for Russia
  - How to Work With Russia
  - Russia’s Tragic Hero
  Uwe Zucchi / DPA-ZUMA Press View More Multimedia »

- # We Read It: 'Voodoo Histories'

  How some conspiracy theories stick

  ##

  David Aaronovitch's 'Voodoo Histories: The Role of the Conspiracy Theory in Shaping Modern History,' picks apart 12 grand conspiracy theories. We read the book and give you the interesting bits, so you don't have to.

  - We Read It: The Full List

  ### Related Articles

  - The Conspiracy-Theory Backlash
  - Chuck Norris Hunts for Secret Vault
  - A Conspiracy Against Diana?
  Getty Images View More Multimedia »

- NEWSWEEKOPEDIA:
- Swine Flu
- Afghanistan
- Health Care
- Iran
- Unemployment

# Daily Scope

## The Globe at a Glance

### Archives Wants Probe of Missing E-mails

The Justice Department is being asked to investigate the “possible unauthorized destruction of e-mail” related to hotly disputed memos about torture, Guantánamo, and warrantless wiretapping.

By MICHAEL ISIKOFF

####

- N.Y. Gov. David Paterson in a Tight Spot
- Harry Reid’s Bizarre Claim About Reconciliation
- A Response to Andrew Sullivan on the ‘Terrorist’ Label
- NEWSWEEK Editor on Misreading ‘Terrorist’ Email Chain
- Obama’s Nuclear Renaissance Hits Roadblock in Vermont

VIEW ARCHIVE »

#### Baddest Breeds

America's most-wanted invasive species.

### Photos: A Look at Healers Who Harm

### In the Know

#### What to read from around the world

- Activists: This Is Why Orcas Don’t Belong in Tanks CSM

  ###### More in:

  KILLER WHALE, SEAWORLD
- A Peek Inside the Biggest Political War Chests POL

  ###### More in:

  CONGRESSIONAL CAMPAIGN, CONTRIBUTIONS
- PETA Uses Tiger Woods Sex Addiction in Ad US

  ###### More in:

  SPAYING, NEUTERING
- Liberal Magazines Less Palatable Under Obama? VF

  ###### More in:

  DEMOCRATS, MAGAZINES

### Newsweek Blogs

- Holly Bailey and Katie Connolly on Washington
  More
  - Health-Care Summit: The Most Fascinating Boring Day Ever 12 hr 43 min ago
- Press, Politics, and Absurdity.
  More
  - Health-Care Summit: The Most Fascinating Boring Day Ever 12 hr 43 min ago
- Mind. Body. Culture.
  More
  - Cord-Blood Banks Called 'Wrong'─But Who's Right?
- Investigative Reporting in Real Time
  More
  - Exclusive: Archives Demands DOJ Explain Missing E-Mails 12 hr 27 min ago
- Economics, Theatrics, Real People
  More
  - A Killer Deal for Russia 19 hr 22 min ago
- Dialed In. Wired Up.
  More
  - For Mobile Payments, It's Hip to Be Square 23 hr 20 min ago

- - 16
  Lisa Miller

  #### Behave! »

  Civility isn't a panacea for our woeful political culture, but at least it could stop the trash talking.

- Julia Baird

  #### Our Era of Dirty Laundry »

  Do tell-all memoirs really help heal?

- Michael Hirsh

  #### Obama’s Pakistan Successes »

  How the U.S. is gaining cooperation in Islamabad.

View More Columnists »

### This Week's Magazine

- U.S. Edition
- International

- GIVE A GIFT
- RENEW
- PAY YOUR BILL

#### Cover Story

462

##### How the GOP Sees It

Katie Connolly, Michael Hirsh and Weston Kosova

What Republicans would do if given carte blanche to run the country.

#### In This Issue

- Red Alert
- Iceberg Ahead

#### More From The Magazine

- Scope
- The Take
- Features
- Culture

- GIVE A GIFT
- RENEW
- PAY YOUR BILL

#### Cover Story

13

##### Europe’s Big Choice

Stefan Theil

With xenophobia on the rise, Europe must decide: open its doors and prosper, or shut them and pay the price.

#### In This Issue

- The Downfall of Human Rights
- A More Dangerous World

#### More From The Magazine

- Scope
- The Take
- Features
- The Culture

### Newsweek on Digg

#### Vancouver 2010: Ring Cycle

NEWSWEEK's Mark Starr blogs from Vancouver. Catch his latest post here.

- Video: Best Olympic Rivalries

- It ought to go with a healthy dose of thanks to George Bush Cheney, on IraqREUTERS
- I'm way fat … But I'm not THERE just yet Kevin SmithREUTERS
- Take my pound of flesh and sleep well Joe Stack CNN
- Sucks Podesta, on the health of American politics POLITICO
- I don't know where his truck actually took him Murray on Sen. BrownBOS HERALD